==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/singleUseObject/MapSingleUseObjectEntityFields.java <==
package org.keycloak.models.map.singleUseObject;
public enum MapSingleUseObjectEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity e) {
            return (String) e.getId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity e, T value) {
            e.setId((String) value);
        }
    },
    EXPIRATION {
        public static final String FIELD_NAME = "Expiration";
        public static final String FIELD_NAME_DASHED = "expiration";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Long.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Long get(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity e) {
            return (Long) e.getExpiration();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity e, T value) {
            e.setExpiration((Long) value);
        }
    },
    NOTES {
        public static final String FIELD_NAME = "Notes";
        public static final String FIELD_NAME_DASHED = "notes";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Map.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapKeyClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapValueClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity e, T value) {
            e.setNotes((java.util.Map<String,String>) value);
        }
        @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> get(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity e) {
            return (java.util.Map<String,String>) e.getNotes();
        }
        @SuppressWarnings("unchecked") @Override public <K> String mapGet(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity e, K key) {
            return (String) e.getNote((String) key);
        }
        @SuppressWarnings("unchecked") @Override public <K, T> void mapPut(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity e, K key, T value) {
            e.setNote((String) key, (String) value);
        }
    },
    OBJECT_KEY {
        public static final String FIELD_NAME = "ObjectKey";
        public static final String FIELD_NAME_DASHED = "object-key";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity e) {
            return (String) e.getObjectKey();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity e, T value) {
            e.setObjectKey((String) value);
        }
    },
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/singleUseObject/MapSingleUseObjectEntityFields.java <==
package org.keycloak.models.map.singleUseObject;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public enum MapSingleUseObjectEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        public static final String FIELD_NAME_CAMEL_CASE = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity e, T value) {
            e.setId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity e) {
            return (String) e.getId();
        }
    },
    EXPIRATION {
        public static final String FIELD_NAME = "Expiration";
        public static final String FIELD_NAME_DASHED = "expiration";
        public static final String FIELD_NAME_CAMEL_CASE = "expiration";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Long.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity e, T value) {
            e.setExpiration((Long) value);
        }
        @SuppressWarnings("unchecked") @Override public Long get(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity e) {
            return (Long) e.getExpiration();
        }
    },
    NOTES {
        public static final String FIELD_NAME = "Notes";
        public static final String FIELD_NAME_DASHED = "notes";
        public static final String FIELD_NAME_CAMEL_CASE = "notes";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Map.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapKeyClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapValueClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity e, T value) {
            e.setNotes((java.util.Map<String,String>) value);
        }
        @SuppressWarnings("unchecked") @Override public <K, T> void mapPut(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity e, K key, T value) {
            e.setNote((String) key, (String) value);
        }
        @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> get(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity e) {
            return (java.util.Map<String,String>) e.getNotes();
        }
        @SuppressWarnings("unchecked") @Override public <K> String mapGet(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity e, K key) {
            return (String) e.getNote((String) key);
        }
    },
    OBJECT_KEY {
        public static final String FIELD_NAME = "ObjectKey";
        public static final String FIELD_NAME_DASHED = "object-key";
        public static final String FIELD_NAME_CAMEL_CASE = "objectKey";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity e, T value) {
            e.setObjectKey((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity e) {
            return (String) e.getObjectKey();
        }
    },
}
